diff --git a/src/wp-admin/includes/schema.php b/src/wp-admin/includes/schema.php
index 0bb6060..fe48d35 100644
--- a/src/wp-admin/includes/schema.php
+++ b/src/wp-admin/includes/schema.php
@@ -1252,7 +1252,7 @@ We hope you enjoy your new site. Thanks!
 		'wpmu_upgrade_site'           => $wp_db_version,
 		'welcome_email'               => $welcome_email,
 		/* translators: %s: site link */
-		'first_post'                  => __( 'Welcome to %s. This is your first post. Edit or delete it, then start blogging!' ),
+		'first_post'                  => __( 'Welcome to %s. This is your first post. Edit or delete it, then start publishing!' ),
 		// @todo - network admins should have a method of editing the network siteurl (used for cookie hash)
 		'siteurl'                     => get_option( 'siteurl' ) . '/',
 		'add_new_users'               => '0',
diff --git a/src/wp-admin/includes/upgrade.php b/src/wp-admin/includes/upgrade.php
index f8b871d..a1dac36 100644
--- a/src/wp-admin/includes/upgrade.php
+++ b/src/wp-admin/includes/upgrade.php
@@ -63,7 +63,7 @@ if ( ! function_exists( 'wp_install' ) ) :
 
 		update_option( 'siteurl', $guessurl );
 
-		// If not a public blog, don't ping.
+		// If not a public website, don't ping.
 		if ( ! $public ) {
 			update_option( 'default_pingback_flag', 0 );
 		}
@@ -193,7 +193,7 @@ if ( ! function_exists( 'wp_install_defaults' ) ) :
 
 			if ( ! $first_post ) {
 				/* translators: %s: site link */
-				$first_post = __( 'Welcome to %s. This is your first post. Edit or delete it, then start blogging!' );
+				$first_post = __( 'Welcome to %s. This is your first post. Edit or delete it, then start publishing!' );
 			}
 
 			$first_post = sprintf(
@@ -205,7 +205,7 @@ if ( ! function_exists( 'wp_install_defaults' ) ) :
 			$first_post = str_replace( 'SITE_URL', esc_url( network_home_url() ), $first_post );
 			$first_post = str_replace( 'SITE_NAME', get_network()->site_name, $first_post );
 		} else {
-			$first_post = __( 'Welcome to WordPress. This is your first post. Edit or delete it, then start writing!' );
+			$first_post = __( 'Welcome to WordPress. This is your first post. Edit or delete it, then start publishing!' );
 		}
 
 		$wpdb->insert(
diff --git a/wp-config-sample.php b/wp-config-sample.php
index 7312c6e..ed8f9fc 100644
--- a/wp-config-sample.php
+++ b/wp-config-sample.php
@@ -79,7 +79,7 @@ $table_prefix = 'wp_';
  */
 define( 'WP_DEBUG', false );
 
-/* That's all, stop editing! Happy blogging. */
+/* That's all, stop editing! Happy publishing. */
 
 /** Absolute path to the WordPress directory. */
 if ( ! defined( 'ABSPATH' ) ) {

diff --git a/src/wp-admin/includes/network.php b/src/wp-admin/includes/network.php
index 9c05ec8..845d2c0 100644
--- a/src/wp-admin/includes/network.php
+++ b/src/wp-admin/includes/network.php
@@ -466,7 +466,7 @@ function network_step2( $errors = false ) {
 			<li><p>
 			<?php
 			printf(
 				/* translators: 1: wp-config.php, 2: location of wp-config file, 3: translated version of "That's all, stop editing! Happy blogging." */
 				__( 'Add the following to your %1$s file in %2$s <strong>above</strong> the line reading %3$s:' ),
 				'<code>wp-config.php</code>',
 				'<code>' . $location_of_wp_config . '</code>',
@@ -475,7 +475,7 @@ function network_step2( $errors = false ) {
 				 * You can check the localized release package or
 				 * https://i18n.svn.wordpress.org/<locale code>/branches/<wp version>/dist/wp-config-sample.php
 				 */
-				'<code>/* ' . __( 'That&#8217;s all, stop editing! Happy blogging.' ) . ' */</code>'
+				'<code>/* ' . __( 'That&#8217;s all, stop editing! Happy publishing.' ) . ' */</code>'
 			);
 			?>
 			</p>
@@ -466,7 +466,7 @@ function network_step2( $errors = false ) {
 			<?php
 			printf(
-				/* translators: 1: wp-config.php, 2: location of wp-config file, 3: translated version of "That's all, stop editing! Happy blogging." */
+				/* translators: 1: wp-config.php, 2: location of wp-config file, 3: translated version of "That's all, stop editing! Happy publishing." */
 				__( 'Add the following to your %1$s file in %2$s <strong>above</strong> the line reading %3$s:' ),
 				'<code>wp-config.php</code>',